###################################################
### chunk number 1: 
###################################################

library(gMCP)
options(width=140)



###################################################
### chunk number 2: 
###################################################

hnodes <- c("H11", "H21", "H31", "H12", "H22", "H32")
alpha <- c(0.05/3, 0.05/3, 0.05/3, 0, 0, 0)
edges <- list()
edges[["H11"]] <- list(edges=c("H21","H12"), weights=c(1/2, 1/2))
edges[["H21"]] <- list(edges=c("H11","H31","H22"), weights=c(1/3, 1/3, 1/3))
edges[["H31"]] <- list(edges=c("H21","H32"), weights=c(1/2, 1/2))
edges[["H12"]] <- list(edges="H21", weights=1)
edges[["H22"]] <- list(edges=c("H11","H31"), weights=c(1/2, 1/2))
edges[["H32"]] <- list(edges="H21", weights=1)
graph <- new("graphMCP", nodes=hnodes, edgeL=edges, alpha=alpha)
nodeX <- c(H11=100, H21=300, H31=500, H12=100, H22=300, H32=500)
nodeY <- c(H11=300, H21=300, H31=300, H12=100, H22=100, H32=100)
nodeRenderInfo(graph) <- list(nodeX=nodeX, nodeY=nodeY)	
cat(graph2latex(graph, scale=0.7, fontsize="tiny"))

gMCPReport <- function(...) {invisible(NULL)}
graphGUI <- function(...) {invisible(NULL)}
options(digits=4)



###################################################
### chunk number 3: 
###################################################

hnodes <- c("H11", "H21", "H31", "H12", "H22", "H32")
alpha <- c(0.05/3, 0.05/3, 0.05/3, 0, 0, 0)
edges <- list()
edges[["H11"]] <- list(edges=c("H21","H12"), weights=c(1/2, 1/2))
edges[["H21"]] <- list(edges=c("H11","H31","H22"), weights=c(1/3, 1/3, 1/3))
edges[["H31"]] <- list(edges=c("H21","H32"), weights=c(1/2, 1/2))
edges[["H12"]] <- list(edges="H21", weights=1)
edges[["H22"]] <- list(edges=c("H11","H31"), weights=c(1/2, 1/2))
edges[["H32"]] <- list(edges="H21", weights=1)
graph <- new("graphMCP", nodes=hnodes, edgeL=edges, alpha=alpha)



###################################################
### chunk number 4: 
###################################################

print(graph)



###################################################
### chunk number 5: 
###################################################

nodeX <- c(H11=100, H21=300, H31=500, H12=100, H22=300, H32=500)
nodeY <- c(H11=300, H21=300, H31=300, H12=100, H22=100, H32=100)
nodeRenderInfo(graph) <- list(nodeX=nodeX, nodeY=nodeY)	



###################################################
### chunk number 6: 
###################################################

cat(graph2latex(graph))



###################################################
### chunk number 7: 
###################################################

edgeData(graph, "H11", "H21", "labelX") <- 200
edgeData(graph, "H11", "H21", "labelY") <- 80



###################################################
### chunk number 8: 
###################################################

graphGUI("graph")



###################################################
### chunk number 9: 
###################################################

graph <- createGraphFromBretzEtAl()

# We can reject a single node:
print(rejectNode(graph, "H11"))

# Or given a vector of pvalues let the function gMCP do all the work:  
pvalues <- c(0.1, 0.008, 0.005, 0.15, 0.04, 0.006)
result <- gMCP(graph, pvalues)
print(result)



###################################################
### chunk number 10: 
###################################################

cat(graph2latex(result@graphs[[4]], scale=0.7, fontsize="tiny"))



###################################################
### chunk number 11: 
###################################################

gMCPReport(result, "Report.tex")



###################################################
### chunk number 12: 
###################################################

pval <- c(0.02,0.055,0.012)

df <- 9
# Sample Standard Deviations:
s <- c(1.2, 0.8, 1.7)
# Statistics:
st <- qt(pval/2,df=df, lower.tail=FALSE)
# Estimates:
est <- st*s/sqrt(10)



###################################################
### chunk number 13: 
###################################################
adjPValues(createBonferroniHolmGraph(3), c(0.02,0.055,0.012))@adjPValues

# Estimates:
est <- c("H1"=0.9101444, "H2"=0.4485153, "H3"=1.4568271)
# Sample standard deviations:
ssd <- c("H1"=1.2, "H2"=0.8, "H3"=1.7)

simConfint(createBonferroniHolmGraph(3),
		pvalues  = c(0.02,0.055,0.012), 
		confint = function(node, alpha) {
			est[node]+c(-1,1)*qt(1-alpha/2,df=9)*ssd[node]/sqrt(10)
		})



###################################################
### chunk number 14: 
###################################################

cat(graph2latex(result@graphs[[3]], pvalues=pvalues, scale=0.7, fontsize="tiny"))



